@@ -6,7 +6,9 @@ IMG_CLASSIFY = [['模特图', '模特上身图', '模特上身正面'], ['模特
                 ['模特图', '模特全身图', '模特全身正面'], ['模特图', '模特全身图', '模特全身侧面'], ['模特图', '模特全身图', '模特全身背面'],
                 ['细节图', '面料'], ['细节图', '领部'], ['细节图', '肩部'], ['细节图', '腰部'], ['细节图', '衣袖'], ['细节图', '下摆'],
                 ['细节图', '口袋'], ['细节图', '门襟'], ['细节图', '内衬'], ['细节图', '图案'], ['细节图', '裤脚'],
+                ['细节图-鞋子', '鞋头'], ['细节图-鞋子', '鞋跟/鞋帮'], ['细节图-鞋子', '鞋口'], ['细节图-鞋子', '鞋底'], ['细节图-鞋子', '鞋标'],
                 ['平铺图', '平铺图背面'], ['平铺图', '平铺图正面'], ['平铺图', '平铺图侧面'],
+                ['静物图-鞋子', '鞋子'],
                 ['资质图', '吊牌图'], ['资质图', '洗水唛'],
                 ['动图']
                 ]
@@ -17,6 +19,9 @@ CROP_TYPE = {
     'm_bo': ['模特下身正面', '模特下身侧面', '模特下身背面'],
     'm_f': ['模特全身正面', '模特全身侧面', '模特全身背面'],
     't': ['平铺图背面', '平铺图正面', '平铺图侧面'],
+    'shoes': ['前面', '后面', '鞋顶面', '鞋靴底面',
+              '左侧45度', '左侧135度', '右侧45度',
+              '右侧135度'],
     'b': ['资质图', '吊牌图', '洗水唛'],
     'g': ['动图'],
 }
@@ -83,11 +88,16 @@ class Image:
         self.humans = Human(image_analysis)
         self.cloths = Cloths(image_analysis)
 
+        self.shoes = Shoes(image_analysis)
+
         self.image_analysis = image_analysis
         # 获取主商品
         self.crop_point = self.deal_crop_key_point()
         # 获取图片背景图
         self.image_background = self.deal_image_background()
+        self.shoe_toe_cap = data.get("shoe_toe_cap", "其他")
+        self.shoe_topline = data.get("shoe_topline", "其他")
+        self.shoe_number = data.get("shoe_number", "其他")
 
         self.image_detail = ImageDetail()
         self.detail_point = {}  # {'裁剪模特帽子':{},}
@@ -291,37 +301,52 @@ class Image:
                             'other-category',
                     },
                 ]'''
-        cat_mapping = {'model': '模特', 'top': '上身', 'up': "胸像", "down": "下身", "all": "全身",
-                       'tile': "平铺图",
-                       "detail": "细节图", "fabric": "面料", "other": "其他",
-                       "intelligence": "", 'drop': "吊牌图", 'tag': "洗水唛",
-                       "positive": "正面", "side": "侧面", "back": "背面",
-                       "sweep": "下摆", "lining": "内衬", "pocket": "口袋",
-                       "pattern": "图案", "shoulder": "肩部", "waist": "腰部",
-                       "sleeve": "衣袖", "leg": "裤脚", "stay": "门襟",
-                       "collar": "领部",
-                       "gif": "动图"
-                       }
+        # cat_mapping = {'model': '模特', 'top': '上身', 'up': "胸像", "down": "下身", "all": "全身",
+        #                'tile': "平铺图",
+        #                "detail": "细节图", "fabric": "面料", "other": "其他",
+        #                "intelligence": "", 'drop': "吊牌图", 'tag': "洗水唛",
+        #                "positive": "正面", "side": "侧面", "back": "背面",
+        #                "sweep": "下摆", "lining": "内衬", "pocket": "口袋",
+        #                "pattern": "图案", "shoulder": "肩部", "waist": "腰部",
+        #                "sleeve": "衣袖", "leg": "裤脚", "stay": "门襟",
+        #                "collar": "领部",
+        #                "gif": "动图",
+        #                }
+        storage_to_slot = {'model-top_positive': '模特上身正面', 'model-top_side': '模特上身侧面', 'model-top_back': '模特上身背面',
+                           'model-up_positive': '模特胸像正面', 'model-up_side': '模特胸像侧面', 'model-up_back': '模特胸像背面',
+                           'model-down_positive': '模特下身正面', 'model-down_side': '模特下身侧面', 'model-down_back': '模特下身背面',
+                           'model-all_positive': '模特全身正面', 'model-all_side': '模特全身侧面', 'model-all_back': '模特全身背面',
+                           'tile_positive': '平铺图正面', 'tile_back': '平铺图背面', 'tile_side': '平铺图侧面',
+                           'tile-shoes_shoes': '鞋子',
+                           'detail_sweep': '下摆', 'detail_lining': '内衬', 'detail_pocket': '口袋',
+                           'detail_pattern': '图案', 'detail_shoulder': '肩部', 'detail_waist': '腰部', 'detail_sleeve': '衣袖',
+                           'detail_leg': '裤脚', 'detail_stay': '门襟', 'detail_fabric': '面料', 'detail_collar': '领部',
+                           'detail_other': '其他',
+                           'detail-shoes_toe': '鞋头', 'detail-shoes_heel': '鞋跟/鞋帮',
+                           'detail-shoes_soles': '鞋底', 'detail-shoes_mouth': '鞋口', 'detail-shoes_label': '鞋标',
+                           'intelligence_drop': '吊牌图', 'intelligence_tag': '洗水唛', 'gif': '动图',
+                           'other': '其他'}
         try:
             # 素材中心，分类不存在 或 不存在识别分类，则按照ai识别结果的分类处理
             if not image_classification or ('no-watch' in image_classification):
                 return '未识别'
-            # 其他分类
-            if '_' not in image_classification:
-                return cat_mapping[image_classification]
-            cat, sub_category = image_classification.split('_')
-            if '-' not in cat:
-                if sub_category != "other":
-                    if cat == 'tile':
-                        return cat_mapping[cat] + cat_mapping[sub_category]
-                    return cat_mapping[sub_category]
-                if cat == 'detail':
-                    # 来个默认细节图
-                    return "细节图"
-                # 保持原有识别
-                return self.ai_image_classification
-            model, body = cat.split('-')
-            return cat_mapping[model] + cat_mapping[body] + cat_mapping[sub_category]
+            return storage_to_slot.get(image_classification, '未识别')
+            # # 其他分类
+            # if '_' not in image_classification:
+            #     return cat_mapping[image_classification]
+            # cat, sub_category = image_classification.split('_')
+            # if '-' not in cat:
+            #     if sub_category != "other":
+            #         if cat == 'tile':
+            #             return cat_mapping[cat] + cat_mapping[sub_category]
+            #         return cat_mapping[sub_category]
+            #     if cat == 'detail':
+            #         # 来个默认细节图
+            #         return "细节图"
+            #     # 保持原有识别
+            #     return self.ai_image_classification
+            # model, body = cat.split('-')
+            # return cat_mapping[model] + cat_mapping[body] + cat_mapping[sub_category]
         except Exception as e:
             # logging.error(f"图片{self.filename}, 分类解析失败: {e}", exc_info=True)
             return '未识别'
@@ -388,6 +413,7 @@ class Image:
 
         self.cloths.cloth_classify = cloth_classify  # 期望的衣服
         crop_point_dict = self.cloths.deal_cloth_crop_point(crop_point_dict)
+        crop_point_dict = self.shoes.deal_shoes_crop_point(crop_point_dict)
         self.crop_point = crop_point_dict
         return crop_point_dict
 
@@ -463,7 +489,6 @@ class Human:
         self.human_body_width = None
         self.human_bodies_list = self.ai_human_pose(image_analysis.get('human_pose'))
 
-
     def calculate_mouth(self, ai_crop_point_dict):
         """
         1.根据 眼镜 鼻子 计算嘴巴的位置
@@ -482,13 +507,22 @@ class Human:
                 'bottom_site': (nose_x, mouth_y)
             }
 
-        if 'eye' not in ai_crop_point_dict.keys() and 'nose' not in ai_crop_point_dict.keys() \
-                and not self.head and 'human_top' in ai_crop_point_dict.keys():
-            ai_crop_point_dict.pop('human_top')
+        # if 'eye' not in ai_crop_point_dict.keys() and 'nose' not in ai_crop_point_dict.keys() \
+        #         and not self.head and 'human_top' in ai_crop_point_dict.keys():
+        #     ai_crop_point_dict.pop('human_top')
 
         if 'ankle' not in ai_crop_point_dict.keys() and 'human_bottom' in ai_crop_point_dict.keys():
             ai_crop_point_dict.pop('human_bottom')
 
+        # 先修改头顶的逻辑，暂时没时间测脚底的
+        top_padding = ai_crop_point_dict['human_top']['top_site'][1] * self.image_height
+        if top_padding < 5:
+            ai_crop_point_dict.pop('human_top')
+
+        # bottom_padding = (1 - ai_crop_point_dict['human_bottom']['bottom_site'][1]) * self.image_height
+        # if bottom_padding < 5:
+        #     ai_crop_point_dict.pop('human_bottom')
+
         return ai_crop_point_dict
 
     def calculate_mandible_crop_point(self, face, human_keypoint_list):
@@ -647,7 +681,8 @@ class Human:
 
         for i, human in enumerate(human_bodies_list):
             # ['右踝', '右膝', '右臀', '左臀', '左膝', '左踝', '腰', '脊柱', '颈', '头', '右腕', '右肘', '右肩', '左肩', '左肘', '左腕']
-            r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = human['keypoints']
+            r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = \
+            human['keypoints']
 
             if hea[2] > 0:
                 self.head = True
@@ -1010,6 +1045,93 @@ class Brand:
         return crop_point_dict
 
 
+class Shoes:
+    # 鞋类识别
+    def __init__(self, image_analysis):
+        self.image_analysis = image_analysis
+        self.threshold = 0.6  # 小于0.6不可信
+        self.shoes_list = self.ai_shoes_info(image_analysis.get("recognition"))
+
+    def ai_shoes_info(self, shoes_json):
+        '''计算各个鞋的分类 及box '''
+
+        if not shoes_json:
+            return []
+
+        shoes_list = []
+        try:
+            shoes_info = json.loads(shoes_json)
+            # 获取cloth
+            if not shoes_info.get('clothes'):
+                return []
+            self.image_width, self.image_height = shoes_info['image']['width'], shoes_info['image']['height']
+            for one_shoes in shoes_info['clothes']:
+                if one_shoes['confidence'] < self.threshold:  # 置信度过低
+                    continue
+                if one_shoes['category_id'] != 8:  # 类型不是鞋子
+                    continue
+                shoes = self.deal_shoes(one_shoes)
+                shoes_list.append(shoes)
+        except Exception:
+            raise Exception(f"ai识别结果-资质图box-解析失败: {json.dumps(self.image_analysis)}")
+            # logging.error(f"ai识别结果-资质图box-解析失败: {json.dumps(self.image_analysis)} ", exc_info=True)
+        return shoes_list
+
+    def deal_shoes(self, one_shoes):
+        '''处理下 每个资质图的 box cat_id cat_name confidence'''
+
+        shoes = dict()
+
+        #  服装的区域
+        shoes['box'] = [
+            one_shoes['bbox'][0] / self.image_width,
+            one_shoes['bbox'][1] / self.image_height,
+            one_shoes['bbox'][2] / self.image_width,
+            one_shoes['bbox'][3] / self.image_height
+        ]
+
+        shoes['cat_id'] = one_shoes['category_id']  # 服装分类id
+        shoes['cat_name'] = one_shoes['category']  # 资质图分类name
+        return shoes
+
+    def deal_shoes_crop_point(self, crop_point_dict):
+        if not self.shoes_list:
+            crop_point_dict['shoes_top'] = {
+                'top_site': [0, 0], 'bottom_site': [1, 1]
+            }
+            crop_point_dict['shoes_bottom'] = {
+                'top_site': [0, 0], 'bottom_site': [1, 1]
+            }
+            return crop_point_dict
+
+        for shoes in self.shoes_list:
+            crop_point_dict = self.shoes_crop_point(shoes, crop_point_dict)
+        return crop_point_dict
+
+    def shoes_crop_point(self, shoes, crop_point_dict):
+        # 鞋上边: shoes_top
+        # 鞋下边: shoes_bottom
+
+        shoes_box = shoes['box']
+        if not crop_point_dict.get('shoes_top'):
+            point = dict()
+            point['top_site'] = shoes_box[0], shoes_box[1]
+            point['bottom_site'] = shoes_box[2], shoes_box[3]
+            crop_point_dict['shoes_top'] = crop_point_dict['shoes_bottom'] = point
+            return crop_point_dict
+
+        shoes_top_site = crop_point_dict['shoes_top']['top_site']
+        shoes_bottom_site = crop_point_dict['shoes_bottom']['bottom_site']
+        # 取最小
+        crop_point_dict['shoes_top']['top_site'] = min(shoes_top_site[0], shoes_box[0]), min(shoes_top_site[1],
+                                                                                             shoes_box[1])
+        # 取最大
+        crop_point_dict['shoes_top']['bottom_site'] = max(shoes_bottom_site[0], shoes_box[2]), max(
+            shoes_bottom_site[1], shoes_box[3])
+        crop_point_dict['shoes_bottom'] = crop_point_dict['shoes_top']
+        return crop_point_dict
+
+
 class ImageDetail:
     """
     TB链接：https://thoughts.teambition.com/workspaces/5e37b6adf0f331001a9c172d/docs/607e874e4cc5830001d956c7
