@@ -140,9 +140,10 @@ class ImageCrop:
         self.si = ShouldIndex()
         # 裁剪点 向上向下兼容顺序顺序
         self.crop_sequence = ['pic_top', 'human_top', 'eye', 'nose', 'ear', 'mouth', 'mandible', 'shoulder',
-                              'elbow',
-                              'wrist', "waist", 'hip', 'knee', 'ankle', 'human_bottom', 'pic_bottom']
-        self.garment_crop_sequence = ['pic_top', 'human_top', 'garment_top', 'garment_bottom', 'human_bottom',
+                              'elbow', 'wrist', "waist", 'hip', 'knee', 'ankle',
+                              'shoes_top', 'shoes_bottom', 'human_bottom', 'pic_bottom']
+        self.garment_crop_sequence = ['pic_top', 'human_top', 'garment_top', 'garment_bottom',
+                                      'shoes_top', 'shoes_bottom', 'human_bottom',
                                       'pic_bottom']
 
         # 记录图片每一步的裁剪流程
@@ -234,6 +235,10 @@ class ImageCrop:
 
         x1 = max(left - padding_left, 0)
         x2 = min(right + padding_right, 1)
+
+        padding_top = (bottom - top) / max((1 - padding_top - padding_bottom), 0.01) * padding_top
+        padding_bottom = (bottom - top) / max((1 - padding_top - padding_bottom), 0.01) * padding_bottom
+
         y1 = max(top - padding_top, 0)
         y2 = min(bottom + padding_bottom, 1)
 
@@ -594,6 +599,11 @@ class ImageCrop:
                 self_adaption_height_crop(0, 1, get_crop_point_result_dict, [slot_width, slot_height], img)
             amend_layout_height = 0  # 历史遗留问题，留着就行
             return crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height, img.width, img.height
+        elif crop_method == 'e':  # 扩边裁剪
+            crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height = self.__extension_crop(
+                0, 1, {'x1': 0, 'x2': 1}, [slot_width, slot_height], img
+            )
+            return crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height, img.width, img.height
         else:
             return self.center_crop(slot_width, slot_height, img.width, img.height)
 
@@ -677,12 +687,24 @@ class ImageCrop:
             crop_left = crop_top_site[0]
             crop_right = crop_bottom_site[0]
             self.si.get_crop_site(['garment_top', 'garment_bottom'], ['garment_top', 'garment_bottom'])
+
+        elif img.img_crop_type == SHOES:  # 鞋类静物图
+            crop_top_site = img.crop_point.get('shoes_top',
+                                               {'top_site': [0, 0], 'bottom_site': [1, 1]})['top_site']
+            crop_bottom_site = img.crop_point.get('shoes_bottom',
+                                                  {'top_site': [0, 0], 'bottom_site': [1, 1]})['bottom_site']
+
+            crop_top = crop_top_site[1]
+            crop_bottom = crop_bottom_site[1]
+            crop_left = crop_top_site[0]
+            crop_right = crop_bottom_site[0]
+            self.si.get_crop_site(['shoes_top', 'shoes_bottom'], ['shoes_top', 'shoes_bottom'])
+
         else:  # 模特图
             top_site = crop_parameter.get(TOP_SITE)
             bottom_site = crop_parameter.get(BOTTOM_SITE)
-            # 取裁剪点/兼容的裁剪点
+            # 取裁剪点 取不到则 图片边缘
             #  Todo 裁剪点 顺序
-
             crop_top_site, crop_top_name = self._from_img_get_top_site(img.crop_point, top_site)
             crop_bottom_site, crop_bottom_name = self._from_img_get_bottom_site(img.crop_point, bottom_site)
 
@@ -755,48 +777,54 @@ class ImageCrop:
         return crop_left, crop_right
 
     def _from_img_get_top_site(self, crop_point, top_site):
-        if top_site not in self.crop_sequence:
-            flag_index = self.garment_crop_sequence.index(top_site)
-            crop_top, crop_top_name = None, None
-            while flag_index >= 0:
-                crop_top, crop_top_name = crop_point.get(self.garment_crop_sequence[flag_index]), \
-                                          self.garment_crop_sequence[flag_index]
-                if crop_top:
-                    break
-                flag_index -= 1
-            return crop_top['top_site'], crop_top_name
+        # if top_site not in self.crop_sequence:
+        #     flag_index = self.garment_crop_sequence.index(top_site)
+        #     crop_top, crop_top_name = None, None
+        #     while flag_index >= 0:
+        #         crop_top, crop_top_name = crop_point.get(self.garment_crop_sequence[flag_index]), \
+        #                                   self.garment_crop_sequence[flag_index]
+        #         if crop_top:
+        #             break
+        #         flag_index -= 1
+        #     return crop_top['top_site'], crop_top_name
+        #
+        # flag_index = self.crop_sequence.index(top_site)
+        # crop_top, crop_top_name = None, None
+        # while flag_index >= 0:
+        #     crop_top, crop_top_name = crop_point.get(self.crop_sequence[flag_index]), self.crop_sequence[flag_index]
+        #     if crop_top:
+        #         break
+        #     flag_index -= 1
 
-        flag_index = self.crop_sequence.index(top_site)
-        crop_top, crop_top_name = None, None
-        while flag_index >= 0:
-            crop_top, crop_top_name = crop_point.get(self.crop_sequence[flag_index]), self.crop_sequence[flag_index]
-            if crop_top:
-                break
-            flag_index -= 1
-        return crop_top['top_site'], crop_top_name
+        if top_site in crop_point.keys():
+            return crop_point[top_site]['top_site'], top_site
+
+        return crop_point['pic_top']['top_site'], 'pic_top'
 
     def _from_img_get_bottom_site(self, crop_point, bottom_site):
-        if bottom_site not in self.crop_sequence:
-            flag_index = self.garment_crop_sequence.index(bottom_site)
-            crop_bottom, crop_bottom_name = None, None
-            while flag_index < len(self.crop_sequence):
-                crop_bottom, crop_bottom_name = crop_point.get(self.garment_crop_sequence[flag_index]), \
-                                                self.garment_crop_sequence[
-                                                    flag_index]
-                if crop_bottom:
-                    break
-                flag_index += 1
-            return crop_bottom['bottom_site'], crop_bottom_name
-
-        flag_index = self.crop_sequence.index(bottom_site)
-        crop_bottom, crop_bottom_name = None, None
-        while flag_index < len(self.crop_sequence):
-            crop_bottom, crop_bottom_name = crop_point.get(self.crop_sequence[flag_index]), self.crop_sequence[
-                flag_index]
-            if crop_bottom:
-                break
-            flag_index += 1
-        return crop_bottom['bottom_site'], crop_bottom_name
+        # if bottom_site not in self.crop_sequence:
+        #     flag_index = self.garment_crop_sequence.index(bottom_site)
+        #     crop_bottom, crop_bottom_name = None, None
+        #     while flag_index < len(self.crop_sequence):
+        #         crop_bottom, crop_bottom_name = crop_point.get(self.garment_crop_sequence[flag_index]), \
+        #                                         self.garment_crop_sequence[
+        #                                             flag_index]
+        #         if crop_bottom:
+        #             break
+        #         flag_index += 1
+        #     return crop_bottom['bottom_site'], crop_bottom_name
+        #
+        # flag_index = self.crop_sequence.index(bottom_site)
+        # crop_bottom, crop_bottom_name = None, None
+        # while flag_index < len(self.crop_sequence):
+        #     crop_bottom, crop_bottom_name = crop_point.get(self.crop_sequence[flag_index]), self.crop_sequence[
+        #         flag_index]
+        #     if crop_bottom:
+        #         break
+        #     flag_index += 1
+        if bottom_site in crop_point.keys():
+            return crop_point[bottom_site]['bottom_site'], bottom_site
+        return crop_point['pic_bottom']['bottom_site'], 'pic_bottom'
 
     def _alternative_interest_center(self, center, slot_height_or_width, transform_height_or_width,
                                      interest_left_or_top,
